crabnet.data.element\_properties package
========================================

Module contents
---------------

.. automodule:: crabnet.data.element_properties
   :members:
   :undoc-members:
   :show-inheritance:
